summaryrefslogtreecommitdiffstats
path: root/templates/annotated/basicapp.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/basicapp.py')
-rw-r--r--templates/annotated/basicapp.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/basicapp.py b/templates/annotated/basicapp.py
index b5abe80..a725004 100644
--- a/templates/annotated/basicapp.py
+++ b/templates/annotated/basicapp.py
@@ -35,7 +35,7 @@ copyright holder.
import sys
-from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData
from tdeui import KMainWindow
"""
@@ -58,17 +58,17 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
# set up some basic information about the program in
# a KAboutData object - this affects the application's
# title bar caption and makes it easy to set up a
# Help | About dialog box for your app
appName = "some app"
programName = "some program"
description = "A basic application template"
-license = KAboutData.License_GPL
+license = TDEAboutData.License_GPL
version = "1.0"
copyright = "(C) 2003 whoever the author is"
-aboutData = KAboutData (appName, programName, version, description, license, copyright)
+aboutData = TDEAboutData (appName, programName, version, description, license, copyright)
# you can add the names of the app's authors here
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
@@ -58,17 +58,17 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
# set up some basic information about the program in
-# a KAboutData object - this affects the application's
+# a TDEAboutData object - this affects the application's
# title bar caption and makes it easy to set up a
# Help | About dialog box for your app